==> seleniumbase-1.63.19.tar.gz: seleniumbase-1.63.19/help_docs/happy_customers.md <==
<h4> Here are some organizations that have used SeleniumBase:</h4>

* [MIT](https://web.mit.edu/)
* [iboss](https://www.iboss.com/)
* [HubSpot](https://www.hubspot.com/)
* [Autodesk](https://www.autodesk.com/)
* [Veracode](https://www.veracode.com/)
* [Broadcom](https://www.broadcom.com/)
* [Thoma Bravo](https://www.thomabravo.com/)
* [Expedia Group](https://lifeatexpediagroup.com/)
* [Texture Health](https://www.texturehealth.com/)
* [Harvard Medical School](https://hms.harvard.edu/)
* [Mississippi State University](https://www.msstate.edu/)
* [Queen's University](https://www.queensu.ca/)
* [L1NNA Laboratory](https://l1nna.com/)
* [CA Technologies](https://www.ca.com/)
* [Raid The Room](https://raidtheroom.com/)
* [First American](https://www.firstam.com/)
* [Origin Energy](https://www.originenergy.com.au/)
* [InterSystems](https://www.intersystems.com/)
* [StreamSets](https://streamsets.com/)
* [NerdVision](https://www.nerd.vision/)
* [Cellebrite](https://www.cellebrite.com/en/home/)
* [GeoNode](http://geonode.org/)
* [VMware](https://www.vmware.com/)
* [Ark PES](https://www.arkpes.com/)
* [Akamai](https://www.akamai.com/)
* [WPILib](https://wpilib.org/)
* [Yandex](https://yandex.ru/)
* [Baidu](https://www.baidu.com/)
* [Iver](https://www.iver.com/)
* [HqO](https://www.hqo.co/)
* And more...

<h3>Case Study: (<i>HubSpot</i>)</h3>

In addition to using SeleniumBase for testing the UI of their content management system, HubSpot used SeleniumBase to automate the migration of website pages from their old CMS to their new one, which saved them over one million USD and a significant amount of time.

Learn how HubSpot uses SeleniumBase for website testing by reading: [Automated Testing with Selenium](https://dev.hubspot.com/blog/bid/88880/Automated-Integration-Testing-with-Selenium-at-HubSpot#hs_cos_wrapper_name)

For more reading about automation at HubSpot, see: [The Classic "QA Team" is Obsolete](https://product.hubspot.com/blog/the-classic-qa-team-is-obsolete#hs_cos_wrapper_name)

==> seleniumbase-3.5.9.tar.gz: seleniumbase-3.5.9/help_docs/happy_customers.md <==
<h4> Here are some organizations that have grown their automation with SeleniumBase:</h4>

* [MIT](https://web.mit.edu/)
* [iboss](https://www.iboss.com/)
* [Akamai](https://www.akamai.com/)
* [HubSpot](https://www.hubspot.com/)
* [Veracode](https://www.veracode.com/)
* [Autodesk](https://www.autodesk.com/)
* [Broadcom](https://www.broadcom.com/)
* [FortressIQ](https://www.fortressiq.com/)
* [Thoma Bravo](https://www.thomabravo.com/)
* [ASICS Digital](https://www.asicsdigital.com/)
* [Expedia Group](https://lifeatexpediagroup.com/)
* [Texture Health](https://www.texturehealth.com/)
* [ActiveCampaign](https://www.activecampaign.com/)
* [Harvard Medical School](https://hms.harvard.edu/)
* [Singapore Institute of Tech](https://www.singaporetech.edu.sg)
* [Mississippi State University](https://www.msstate.edu/)
* [Queen's University](https://www.queensu.ca/)
* [L1NNA Laboratory](https://l1nna.com/)
* [Thomson Reuters](https://www.thomsonreuters.com/)
* [CA Technologies](https://www.ca.com/)
* [Raid The Room](https://raidtheroom.com/)
* [First American](https://www.firstam.com/)
* [Origin Energy](https://www.originenergy.com.au/)
* [Develop Soft](https://www.developsoft.com/)
* [InterSystems](https://www.intersystems.com/)
* [StreamSets](https://streamsets.com/)
* [NerdVision](https://www.nerd.vision/)
* [SenseTime](https://www.sensetime.com/en)
* [Aeturnum](https://aeturnum.com/)
* [Cellebrite](https://www.cellebrite.com/en/home/)
* [Ben Fatto](http://www.benfatto.net.br)
* [GeoNode](http://geonode.org/)
* [Streamlit](https://streamlit.io/)
* [VMware](https://www.vmware.com/)
* [Rakuten](https://global.rakuten.com/corp/about/)
* [Nagarro](https://www.nagarro.com/en)
* [Ark PES](https://www.arkpes.com/)
* [Evereve](https://evereve.com/)
* [WPILib](https://wpilib.org/)
* [Yandex](https://yandex.ru/)
* [netLex](https://netlex.io/en/)
* [Alokin](https://alokin.in/)
* [Cubic](https://www.cubic.com/)
* [Baidu](https://www.baidu.com/)
* [HqO](https://www.hqo.co/)
* [PDS](https://www.pdsinc.com/)
* [Pico](https://trypico.com/)
* [Iver](https://www.iver.com/)
* And more...

<h3>Case Study: (<i>HubSpot</i>)</h3>

In addition to using SeleniumBase for testing the UI of their content management system, HubSpot used SeleniumBase to automate the migration of website pages from their old CMS to their new one, which saved them over one million USD and a significant amount of time.

Learn how HubSpot uses SeleniumBase for website testing by reading: [Automated Testing with Selenium](https://dev.hubspot.com/blog/bid/88880/Automated-Integration-Testing-with-Selenium-at-HubSpot#hs_cos_wrapper_name)

For more reading about automation at HubSpot, see: [The Classic "QA Team" is Obsolete](https://product.hubspot.com/blog/the-classic-qa-team-is-obsolete#hs_cos_wrapper_name)
